@@ -18,6 +18,7 @@ CRITERIA_TRUE = 10
 CRITERIA_FALSE = 11
 CRITERIA_NULL = 12
 CRITERIA_NOT_NULL = 13
+CRITERIA_CONTAINS_IGNORE_CASE = 14
 
 ORDER_BY_NONE = 0
 ORDER_BY_ASC = 1
@@ -28,6 +29,7 @@ TEXT_CRITERIA_SET = [
     CRITERIA_EQUAL,
     CRITERIA_NOT_EQUAL,
     CRITERIA_CONTAINS,
+    CRITERIA_CONTAINS_IGNORE_CASE,
     CRITERIA_STARTS_WITH,
     CRITERIA_ENDS_WITH,
     CRITERIA_NULL,
@@ -72,6 +74,7 @@ CRITERIA_SET = {
     CRITERIA_GREATER_THAN: "plus grand que",
     CRITERIA_GREATER_THAN_OR_EQUAL: "plus grand ou égal",
     CRITERIA_CONTAINS: "contient",
+    CRITERIA_CONTAINS_IGNORE_CASE: "contient (ignore-case)",
     CRITERIA_STARTS_WITH: "commence par",
     CRITERIA_ENDS_WITH: "termine par",
     CRITERIA_TRUE: "vrai",
@@ -80,6 +83,20 @@ CRITERIA_SET = {
     CRITERIA_NOT_NULL: "non vide",
 }
 
+FORM_TEMPLATE_ITEM_TYPE_TEXT = 0
+FORM_TEMPLATE_ITEM_TYPE_DATE = 1
+FORM_TEMPLATE_ITEM_TYPE_BOOLEAN = 2
+FORM_TEMPLATE_ITEM_TYPE_INTEGER = 3
+FORM_TEMPLATE_ITEM_TYPE_DOUBLE = 4
+
+FORM_TEMPLATE_ITEM_TYPE_SET = {
+    FORM_TEMPLATE_ITEM_TYPE_TEXT: "texte",
+    FORM_TEMPLATE_ITEM_TYPE_DATE: "date",
+    FORM_TEMPLATE_ITEM_TYPE_BOOLEAN: "booléen",
+    FORM_TEMPLATE_ITEM_TYPE_INTEGER: "entier",
+    FORM_TEMPLATE_ITEM_TYPE_DOUBLE: "double"
+}
+
 
 class Log(models.Model):
     user: User = models.ForeignKey(User, on_delete=models.DO_NOTHING, null=True, related_name='actor')
@@ -312,12 +329,8 @@ class Condition(models.Model):
         return self.label_as_str() + ' ' + self.criteria_as_str() + ' ' + self.value
 
     def label_as_str(self):
-        grid = self.condition_group.grid() if self.condition_group else None
-        fields = grid.fields() if grid else None
-        for field in fields:
-            if field.key == self.label:
-                return field.label
-        return self.label
+        field = self.get_field()
+        return field.label if field else self.label
 
     def label_with_operator(self, op):
         return str(self.label) + '__' + op
@@ -325,26 +338,44 @@ class Condition(models.Model):
     def criteria_as_str(self):
         return CRITERIA_SET[self.criteria]
 
+    def get_field(self):
+        grid = self.condition_group.grid() if self.condition_group else None
+        fields = grid.fields() if grid else None
+        for field in fields:
+            if field.key == self.label:
+                return field
+        return None
+
     def get_filter(self):
         try:
+
+            # Check values
+            value = self.value
+
+            field = self.get_field()
+            if field and hasattr(field, 'pairs') and field.pairs:
+                value = field.get_value(value)
+
             if self.criteria == CRITERIA_NOT_EQUAL:
-                return ~Q(**{self.label: self.value})
+                return ~Q(**{self.label: value})
             elif self.criteria == CRITERIA_EQUAL:
-                return Q(**{self.label: self.value})
+                return Q(**{self.label: value})
             elif self.criteria == CRITERIA_LESS_THAN:
-                return Q(**{self.label_with_operator('lt'): self.value})
+                return Q(**{self.label_with_operator('lt'): value})
             elif self.criteria == CRITERIA_LESS_THAN_OR_EQUAL:
-                return Q(**{self.label_with_operator('lte'): self.value})
+                return Q(**{self.label_with_operator('lte'): value})
             elif self.criteria == CRITERIA_GREATER_THAN:
-                return Q(**{self.label_with_operator('gt'): self.value})
+                return Q(**{self.label_with_operator('gt'): value})
             elif self.criteria == CRITERIA_GREATER_THAN_OR_EQUAL:
-                return Q(**{self.label_with_operator('gte'): self.value})
+                return Q(**{self.label_with_operator('gte'): value})
             elif self.criteria == CRITERIA_CONTAINS:
-                return Q(**{self.label_with_operator('contains'): self.value})
+                return Q(**{self.label_with_operator('contains'): value})
+            elif self.criteria == CRITERIA_CONTAINS_IGNORE_CASE:
+                return Q(**{self.label_with_operator('icontains'): value})
             elif self.criteria == CRITERIA_STARTS_WITH:
-                return Q(**{self.label_with_operator('startswith'): self.value})
+                return Q(**{self.label_with_operator('startswith'): value})
             elif self.criteria == CRITERIA_ENDS_WITH:
-                return Q(**{self.label_with_operator('endswith'): self.value})
+                return Q(**{self.label_with_operator('endswith'): value})
             elif self.criteria == CRITERIA_TRUE:
                 return Q(**{self.label: True})
             elif self.criteria == CRITERIA_FALSE:
@@ -367,4 +398,58 @@ class Condition(models.Model):
         return condition
 
 
+class FormTemplate(models.Model):
+    name = models.CharField(max_length=255, default='', null=True, blank=True)
+    comment = models.CharField(max_length=255, default='', null=True, blank=True)
+
+    objects = models.Manager()
+
+    def __str__(self):
+        return str(self.name)
+
+    def clone(self):
+        form_template = FormTemplate()
+        form_template.name = self.name + "'"
+        form_template.comment = self.comment
+        form_template.save()
+
+        for item in self.items.all():
+            item.clone(form_template)
+
+        return form_template
+
+
+class FormTemplateItem(models.Model):
+    form_template: FormTemplate = models.ForeignKey(FormTemplate, on_delete=models.DO_NOTHING, related_name='items', null=True)
+
+    label = models.CharField(max_length=255, default='', null=True, blank=True)
+    type = models.IntegerField(default=0)
+    order = models.IntegerField(default=0)
+    comment = models.CharField(max_length=255, default='', null=True, blank=True)
+    optional = models.BooleanField(default=False)
+
+    objects = models.Manager()
+
+    def __str__(self):
+        return str(self.id)
+
+    def as_str(self):
+        return self.label_as_str()
+
+    def id_as_str(self):
+        return 'form_template_item_' + str(self.id)
+
+    def label_as_str(self):
+        field = self.get_field()
+        return field.label if field else self.label
+
+    def clone(self, form_template):
+        form_template_item = FormTemplateItem(form_template=form_template)
+        form_template_item.label = self.label
+        form_template_item.type = self.type
+        form_template_item.order = self.order
+        form_template_item.comment = self.comment
+        form_template_item.optional = self.optional
+        form_template_item.save()
+        return form_template_item
 
