@@ -13,6 +13,17 @@ class TableButton:
         self.action = action
 
 
+class TableButtonGroup:
+    def __init__(self, label, items):
+        self.label = label
+        self.items = items
+
+
+class TableButtonDivider:
+    def __init__(self):
+        None
+
+
 class TableColumn:
     def __init__(self, key, name, type=None, value=None, method=None, link=None, sortable=False):
         self.key = key
