@@ -12,7 +12,7 @@ from email.mime.text import MIMEText
 import pytz
 from PIL import Image
 from django.conf import settings
-from django.core.paginator import Paginator
+from django.core.paginator import Paginator, EmptyPage
 from django.http import HttpResponse
 from django.shortcuts import render
 from django.urls import reverse
@@ -188,20 +188,29 @@ def check_regex(context, label, value, pattern):
 
 
 can_navigate_params = ['sort', 'search']
+can_navigate_params_from_grid = [
+    'grid_id',
+    'grid_sort'
+]
 
 
 def can_navigate(request, context, back):
-    if context and 'back' in context and context['back'] != back:
-        return False
-    for param in can_navigate_params:
-        if param not in request.POST:
-            return False
-    return True
+    #if context and 'back' in context and context['back'] != back:
+    #    return False
+    def has_params(params):
+        for param in params:
+            if param not in request.POST:
+                return False
+        return True
+
+    return has_params(can_navigate_params) or has_params(can_navigate_params_from_grid)
 
 
 def navigate(request, context, items, id):
     for param in can_navigate_params:
         get_param(request, context, param, '')
+    for param in can_navigate_params_from_grid:
+        get_param(request, context, param, '')
 
     if items.first():
 
@@ -220,7 +229,10 @@ def navigate(request, context, items, id):
             size = (paginator_size * 3)
             index = ((paginator_page - 1) * paginator_size)
             page = int(index / size) + 1
-            items = Paginator(items, size).page(page)
+            try:
+                items = Paginator(items, size).page(page)
+            except EmptyPage:
+                page = 0
             index_prev = index
             index_next = index + paginator_size - 1
             index = ((page - 1) * size)
@@ -262,6 +274,12 @@ def paginate(request, context, results, length=15, space=None):
         full_name = space + '.page'
         page = request.session[full_name] if full_name in request.session else 1
 
+    if isinstance(page, str):
+        try:
+            page = int(page)
+        except ValueError:
+            page = 0
+
     size = length
     if 'paginator_size' in request.POST and request.POST['paginator_size']:
         size = int(request.POST['paginator_size'])
