@@ -8,7 +8,7 @@ from foledol.django.utils import get_search, paginate, new_context
 from ..models import Column
 
 
-class ColumnTables(Table):
+class ColumnTable(Table):
     def __init__(self, rows):
         super().__init__(rows, [
             TableColumn('label', "Libellé")
@@ -33,6 +33,6 @@ def column_list(request):
 
     columns = columns.order_by('order')
 
-    context['table'] = ColumnTables(paginate(request, context, columns))
+    context['table'] = ColumnTable(paginate(request, context, columns))
 
     return render(request, 'columns.html', context)
