@@ -11,8 +11,8 @@ from django.utils.translation import gettext as _
 from foledol.django.logger import log
 from foledol.django.models import Grid, ConditionGroup, Condition, ORDER_BY_ASC, ORDER_BY_DESC
 from foledol.django.reports.grid import GridReport
-from foledol.django.templatetags.form_extras import value
-from foledol.django.tools.field import TextField, BooleanField
+from foledol.django.templatetags.form_extras import value, value_as_str
+from foledol.django.tools.field import TextField, DateField, BooleanField
 from foledol.django.tools.form import Form
 from foledol.django.tools.handlers import confirm
 from foledol.django.tools.table import Table, TableColumn
@@ -463,6 +463,10 @@ def get_value(grid, row, column):
     return row[column.label] if grid.group_by else value(row, column.label)
 
 
+def get_value_as_str(grid, row, column):
+    return row[column.label] if grid.group_by else value_as_str(row, column.label)
+
+
 def grid_copy(grid, rows, fields):
     data = ""
 
@@ -481,7 +485,7 @@ def grid_copy(grid, rows, fields):
             if field:
                 if len(line) > 0:
                     line += "\t"
-                line += str(get_value(grid, row, column))
+                line += str(get_value_as_str(grid, row, column))
         data += line
         data += "\n"
     return data
@@ -497,6 +501,8 @@ def grid_export(grid, rows, fields):
     column_header.set_align('center')
     column_header.set_text_wrap(True)
 
+    date_format = workbook.add_format({'num_format': 'dd-mm-yyyy'})
+
     worksheet = workbook.add_worksheet(grid.table)
     worksheet.set_landscape()
 
@@ -512,10 +518,15 @@ def grid_export(grid, rows, fields):
     j = 1
     for row in rows:
         i = 0
-        for column in grid.column_set.all():
+        for column in grid.column_set.all().order_by('order'):
             field = get_field(column.label, fields)
             if field:
-                worksheet.write(j, i, get_value(grid, row, column))
+                if isinstance(field, DateField):
+                    date = get_value(grid, row, column)
+                    if date:
+                        worksheet.write(j, i, date.replace(tzinfo=None), date_format)
+                else:
+                    worksheet.write(j, i, get_value_as_str(grid, row, column))
                 i += 1
         j += 1
 
